| .compute.fixedmc | R Documentation |
Internal function used to evaluate expressions containing objects of type fixedmc.
## S3 method for class 'fixedmc'
.compute(object, env, ...)
object |
An object of type |
env |
Computing environment. |
... |
Not used. |
vector/matrix with means for an object of type mc.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.