dot-compute.fixedsvc: Compute function for svc objects

.compute.fixedsvcR Documentation

Compute function for svc objects

Description

Internal function used to evaluate expressions containing objects of type fixedsvc.

Usage

## S3 method for class 'fixedsvc'
.compute(object, env, ...)

Arguments

object

An object of type svc.

env

Computing environment.

...

Not used.

Value

Matrix with covariances for an object of type svc.


espenmei/svcmr documentation built on March 29, 2025, 1:01 p.m.