dot-update_pm: Updates values in parameter matrix

.update_pmR Documentation

Updates values in parameter matrix

Description

Used during optimization for updating free values in a parameter matrix in both computing environment and model object.

Usage

.update_pm(pm, theta, env_comp)

Arguments

pm

an instance of an pm object.

theta

vector of free model parameters.

env_comp

computing environment where the expression is evaluated and stored.


espenmei/svcmr documentation built on March 29, 2025, 1:01 p.m.