fd_jacobian_svcm: Compute jacobian of expression

View source: R/svcm_main.R

fd_jacobian_svcmR Documentation

Compute jacobian of expression

Description

Computes jacobian of expression containing parameter matrices with finite differences. The output should be a vector. Note that the jacobian is computed with regard to all free parameters in the model.

Usage

fd_jacobian_svcm(mod, form, ...)

Arguments

mod

An object of type svcm

form

An expression for the calculation.

...

Arguments passed to numDeriv::hessian.

Value

Jacobian matrix.


espenmei/svcmr documentation built on March 29, 2025, 1:01 p.m.