| pm | R Documentation |
Creates an object of type pm used to represent parameters in a model.
pm(
nrow = NA,
ncol = NA,
labels = character(),
free = FALSE,
values = NA,
name = NA
)
nrow |
Number of matrix rows. |
ncol |
Number of matrix columns. |
labels |
Vector/matrix with parameter labels. Equal characters defines equality constraints. |
free |
Vector or matrix of logical values defining parameters free or not. |
values |
Vector/matrix with parameter values. Values for free parameters are used as starting values for optimization and values for fixed parameters are constant during optimization. |
name |
Character giving name to model object. Used to reference the parameter matrix in computations. |
An object of class pm.
library(svcm)
S <- pm(nrow = 2, ncol = 2,
labels = c("s11", "s12", "s12", "s22"),
values = c(2, 1, 1, 2),
free = TRUE,
name = "S")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.