| .compute.fixedsvc | R Documentation |
Internal function used to evaluate expressions containing objects of type fixedsvc.
## S3 method for class 'fixedsvc'
.compute(object, env, ...)
object |
An object of type |
env |
Computing environment. |
... |
Not used. |
Matrix with covariances for an object of type svc.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.