| .update_pm | R Documentation |
Used during optimization for updating free values in a parameter matrix in both computing environment and model object.
.update_pm(pm, theta, env_comp)
pm |
an instance of an |
theta |
vector of free model parameters. |
env_comp |
computing environment where the expression is evaluated and stored. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.