| fd_jacobian_svcm | R Documentation |
Computes jacobian of expression containing parameter matrices with finite differences. The output should be a vector. Note that the jacobian is computed with regard to all free parameters in the model.
fd_jacobian_svcm(mod, form, ...)
mod |
An object of type |
form |
An expression for the calculation. |
... |
Arguments passed to |
Jacobian matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.